</div></details><h2id="fields"class="fields small-section-header">Fields<ahref="#fields"class="anchor"></a></h2><spanid="structfield.bracket_token"class="structfield small-section-header"><ahref="#structfield.bracket_token"class="anchor field"></a><code>bracket_token: <aclass="struct"href="token/struct.Bracket.html"title="struct syn::token::Bracket">Bracket</a></code></span><spanid="structfield.elem"class="structfield small-section-header"><ahref="#structfield.elem"class="anchor field"></a><code>elem: <aclass="struct"href="https://doc.rust-lang.org/1.67.0/alloc/boxed/struct.Box.html"title="struct alloc::boxed::Box">Box</a><<aclass="enum"href="enum.Type.html"title="enum syn::Type">Type</a>></code></span><spanid="structfield.semi_token"class="structfield small-section-header"><ahref="#structfield.semi_token"class="anchor field"></a><code>semi_token: <aclass="struct"href="token/struct.Semi.html"title="struct syn::token::Semi">Semi</a></code></span><spanid="structfield.len"class="structfield small-section-header"><ahref="#structfield.len"class="anchor field"></a><code>len: <aclass="enum"href="enum.Expr.html"title="enum syn::Expr">Expr</a></code></span><h2id="trait-implementations"class="small-section-header">Trait Implementations<ahref="#trait-implementations"class="anchor"></a></h2><divid="trait-implementations-list"><detailsclass="rustdoc-toggle implementors-toggle"open><summary><sectionid="impl-Clone-for-TypeArray"class="impl has-srclink"><aclass="srclink rightside"href="../src/syn/gen/clone.rs.html#1915-1924">source</a><ahref="#impl-Clone-for-TypeArray"class="anchor"></a><h3class="code-header">impl <aclass="trait"href="https://doc.rust-lang.org/1.67.0/core/clone/trait.Clone.html"title="trait core::clone::Clone">Clone</a> for <aclass="struct"href="struct.TypeArray.html"title="struct syn::TypeArray">TypeArray</a></h3></section></summary><divclass="impl-items"><detailsclass="rustdoc-toggle method-toggle"open><summary><sectionid="method.clone"class="method trait-impl has-srclink"><aclass="srclink rightside"href="../src/syn/gen/clone.rs.html#1916-1923">source</a><ahref="#method.clone"class="anchor"></a><h4class="code-header">fn <ahref="https://doc.rust-lang.org/1.67.0/core/clone/trait.Clone.html#tymethod.clone"class="fn">clone</a>(&self) -> Self</h4></section></summary><divclass='docblock'>Returns a copy of the value. <ahref="https://doc.rust-lang.org/1.67.0/core/clone/trait.Clone.html#tymethod.clone">Read more</a></div></details><detailsclass="rustdoc-toggle method-toggle"open><summary><sectionid="method.clone_from"class="method trait-impl has-srclink"><spanclass="rightside"><spanclass="since"title="Stable since Rust version 1.0.0">1.0.0</span> · <aclass="srclink"href="https://doc.rust-lang.org/1.67.0/src/core/clone.rs.html#132-134">source</a></span><ahref="#method.clone_from"class="anchor"></a><h4class="code-header">fn <ahref="https://doc.rust-lang.org/1.67.0/core/clone/trait.Clone.html#method.clone_from"class="fn">clone_from</a>(&mut self, source: <aclass="primitive"href="https://doc.rust-lang.org/1.67.0/std/primitive.reference.html">&</a>Self)</h4></section></summary><divclass='docblock'>Performs copy-assignment from <code>source</code>. <ahref="https://doc.rust-lang.org/1.67.0/core/clone/trait.Clone.html#method.clone_from">Read more</a></div></details></div></details><detailsclass="rustdoc-toggle implementors-toggle"open><summary><sectionid="impl-Debug-for-TypeArray"class="impl has-srclink"><aclass="srclink rightside"href="../src/syn/gen/debug.rs.html#2649-2658">source</a><ahref="#impl-Debug-for-TypeArray"class="anchor"></a><h3class="code-header">impl <aclass="trait"href="https://doc.rust-lang.org/1.67.0/core/fmt/trait.Debug.html"title="trait core::fmt::Debug">Debug</a> for <aclass="struct"href="struct.TypeArray.html"title="struct syn::TypeArray">TypeArray</a></h3></section></summary><divclass="impl-items"><detailsclass="rustdoc-toggle method-toggle"open><summary><sectionid=
by <code>==</code>. <ahref="https://doc.rust-lang.org/1.67.0/core/cmp/trait.PartialEq.html#tymethod.eq">Read more</a></div></details><detailsclass="rustdoc-toggle method-toggle"open><summary><sectionid="method.ne"class="method trait-impl has-srclink"><spanclass="rightside"><spanclass="since"title="Stable since Rust version 1.0.0">1.0.0</span> · <aclass="srclink"href="https://doc.rust-lang.org/1.67.0/src/core/cmp.rs.html#229">source</a></span><ahref="#method.ne"class="anchor"></a><h4class="code-header">fn <ahref="https://doc.rust-lang.org/1.67.0/core/cmp/trait.PartialEq.html#method.ne"class="fn">ne</a>(&self, other: <aclass="primitive"href="https://doc.rust-lang.org/1.67.0/std/primitive.reference.html">&</a>Rhs) -><aclass="primitive"href="https://doc.rust-lang.org/1.67.0/std/primitive.bool.html">bool</a></h4></section></summary><divclass='docblock'>This method tests for <code>!=</code>. The default implementation is almost always
sufficient, and should not be overridden without very good reason. <ahref="https://doc.rust-lang.org/1.67.0/core/cmp/trait.PartialEq.html#method.ne">Read more</a></div></details></div></details><detailsclass="rustdoc-toggle implementors-toggle"open><summary><sectionid="impl-ToTokens-for-TypeArray"class="impl has-srclink"><aclass="srclink rightside"href="../src/syn/ty.rs.html#1138-1146">source</a><ahref="#impl-ToTokens-for-TypeArray"class="anchor"></a><h3class="code-header">impl <aclass="trait"href="../quote/to_tokens/trait.ToTokens.html"title="trait quote::to_tokens::ToTokens">ToTokens</a> for <aclass="struct"href="struct.TypeArray.html"title="struct syn::TypeArray">TypeArray</a></h3></section></summary><divclass="impl-items"><detailsclass="rustdoc-toggle method-toggle"open><summary><sectionid="method.to_tokens"class="method trait-impl has-srclink"><aclass="srclink rightside"href="../src/syn/ty.rs.html#1139-1145">source</a><ahref="#method.to_tokens"class="anchor"></a><h4class="code-header">fn <ahref="../quote/to_tokens/trait.ToTokens.html#tymethod.to_tokens"class="fn">to_tokens</a>(&self, tokens: &mut <aclass="struct"href="../proc_macro2/struct.TokenStream.html"title="struct proc_macro2::TokenStream">TokenStream</a>)</h4></section></summary><divclass='docblock'>Write <code>self</code> to the given <code>TokenStream</code>. <ahref="../quote/to_tokens/trait.ToTokens.html#tymethod.to_tokens">Read more</a></div></details><detailsclass="rustdoc-toggle method-toggle"open><summary><sectionid="method.to_token_stream"class="method trait-impl has-srclink"><aclass="srclink rightside"href="../src/quote/to_tokens.rs.html#59">source</a><ahref="#method.to_token_stream"class="anchor"></a><h4class="code-header">fn <ahref="../quote/to_tokens/trait.ToTokens.html#method.to_token_stream"class="fn">to_token_stream</a>(&self) -><aclass="struct"href="../proc_macro2/struct.TokenStream.html"title="struct proc_macro2::TokenStream">TokenStream</a></h4></section></summary><divclass='docblock'>Convert <code>self</code> directly into a <code>TokenStream</code> object. <ahref="../quote/to_tokens/trait.ToTokens.html#method.to_token_stream">Read more</a></div></details><detailsclass="rustdoc-toggle method-toggle"open><summary><sectionid="method.into_token_stream"class="method trait-impl has-srclink"><aclass="srclink rightside"href="../src/quote/to_tokens.rs.html#69-71">source</a><ahref="#method.into_token_stream"class="anchor"></a><h4class="code-header">fn <ahref="../quote/to_tokens/trait.ToTokens.html#method.into_token_stream"class="fn">into_token_stream</a>(self) -><aclass="struct"href="../proc_macro2/struct.TokenStream.html"title="struct proc_macro2::TokenStream">TokenStream</a><spanclass="where fmt-newline">where<br> Self: <aclass="trait"href="https://doc.rust-lang.org/1.67.0/core/marker/trait.Sized.html"title="trait core::marker::Sized">Sized</a>,</span></h4></section></summary><divclass='docblock'>Convert <code>self</code> directly into a <code>TokenStream</code> object. <ahref="../quote/to_tokens/trait.ToTokens.html#method.into_token_stream">Read more</a></div></details></div></details><sectionid="impl-Eq-for-TypeArray"class="impl has-srclink"><aclass="srclink rightside"href="../src/syn/gen/eq.rs.html#1844">source</a><ahref="#impl-Eq-for-TypeArray"class="anchor"></a><h3class="code-header">impl <aclass="trait"href="https://doc.rust-lang.org/1.67.0/core/cmp/trait.Eq.html"title="trait core::cmp::Eq">Eq</a> for <aclass="struct"href="struct.TypeArray.html"title="struct syn::TypeArray">TypeArray</a></h3></section></div><h2id="synthetic-implementations"class="small-section-header">Auto Trait Implementations<ahref="#synthetic-implementations"class="anchor"></a></h2><divid="synthetic-implementations-list"><sectionid="impl-RefUnwindSafe-for-TypeArray"class="impl has-srclink"><ahref="#impl-RefUnwindSafe-for-TypeArray"class="anchor"></a><h3class="code-header">impl <aclass="trait"href="https://doc.rust-lang.org
<p>That is, this conversion is whatever the implementation of
<code><ahref="https://doc.rust-lang.org/1.67.0/core/convert/trait.From.html"title="From">From</a><T> for U</code> chooses to do.</p>
</div></details></div></details><detailsclass="rustdoc-toggle implementors-toggle"><summary><sectionid="impl-Spanned-for-TypeArray"class="impl has-srclink"><aclass="srclink rightside"href="../src/syn/spanned.rs.html#110-114">source</a><ahref="#impl-Spanned-for-TypeArray"class="anchor"></a><h3class="code-header">impl<T><aclass="trait"href="spanned/trait.Spanned.html"title="trait syn::spanned::Spanned">Spanned</a> for T<spanclass="where fmt-newline">where<br> T: Spanned + ?<aclass="trait"href="https://doc.rust-lang.org/1.67.0/core/marker/trait.Sized.html"title="trait core::marker::Sized">Sized</a>,</span></h3></section></summary><divclass="impl-items"><detailsclass="rustdoc-toggle method-toggle"open><summary><sectionid="method.span"class="method trait-impl has-srclink"><aclass="srclink rightside"href="../src/syn/spanned.rs.html#111-113">source</a><ahref="#method.span"class="anchor"></a><h4class="code-header">fn <ahref="spanned/trait.Spanned.html#tymethod.span"class="fn">span</a>(&self) -><aclass="struct"href="../proc_macro2/struct.Span.html"title="struct proc_macro2::Span">Span</a></h4></section></summary><divclass='docblock'>Returns a <code>Span</code> covering the complete contents of this syntax tree
node, or <ahref="../proc_macro2/struct.Span.html#method.call_site"><code>Span::call_site()</code></a> if this node is empty. <ahref="spanned/trait.Spanned.html#tymethod.span">Read more</a></div></details></div></details><detailsclass="rustdoc-toggle implementors-toggle"><summary><sectionid="impl-ToOwned-for-TypeArray"class="impl has-srclink"><aclass="srclink rightside"href="https://doc.rust-lang.org/1.67.0/src/alloc/borrow.rs.html#82">source</a><ahref="#impl-ToOwned-for-TypeArray"class="anchor"></a><h3class="code-header">impl<T><aclass="trait"href="https://doc.rust-lang.org/1.67.0/alloc/borrow/trait.ToOwned.html"title="trait alloc::borrow::ToOwned">ToOwned</a> for T<spanclass="where fmt-newline">where<br> T: <aclass="trait"href="https://doc.rust-lang.org/1.67.0/core/clone/trait.Clone.html"title="trait core::clone::Clone">Clone</a>,</span></h3></section></summary><divclass="impl-items"><detailsclass="rustdoc-toggle"open><summary><sectionid="associatedtype.Owned"class="associatedtype trait-impl has-srclink"><ahref="#associatedtype.Owned"class="anchor"></a><h4class="code-header">type <ahref="https://doc.rust-lang.org/1.67.0/alloc/borrow/trait.ToOwned.html#associatedtype.Owned"class="associatedtype">Owned</a> = T</h4></section></summary><divclass='docblock'>The resulting type after obtaining ownership.</div></details><detailsclass="rustdoc-toggle method-toggle"open><summary><sectionid="method.to_owned"class="method trait-impl has-srclink"><aclass="srclink rightside"href="https://doc.rust-lang.org/1.67.0/src/alloc/borrow.rs.html#87">source</a><ahref="#method.to_owned"class="anchor"></a><h4class="code-header">fn <ahref="https://doc.rust-lang.org/1.67.0/alloc/borrow/trait.ToOwned.html#tymethod.to_owned"class="fn">to_owned</a>(&self) -> T</h4></section></summary><divclass='docblock'>Creates owned data from borrowed data, usually by cloning. <ahref="https://doc.rust-lang.org/1.67.0/alloc/borrow/trait.ToOwned.html#tymethod.to_owned">Read more</a></div></details><detailsclass="rustdoc-toggle method-toggle"open><summary><sectionid="method.clone_into"class="method trait-impl has-srclink"><aclass="srclink rightside"href="https://doc.rust-lang.org/1.67.0/src/alloc/borrow.rs.html#91">source</a><ahref="#method.clone_into"class="anchor"></a><h4class="code-header">fn <ahref="https://doc.rust-lang.org/1.67.0/alloc/borrow/trait.ToOwned.html#method.clone_into"class="fn">clone_into</a>(&self, target: <aclass="primitive"href="https://doc.rust-lang.org/1.67.0/std/primitive.reference.html">&mut </a>T)</h4></section></summary><divclass='docblock'>Uses borrowed data to replace owned data, usually by cloning. <ahref="https://doc.rust-lang.org/1.67.0/alloc/borrow/trait.ToOwned.html#method.clone_into">Read more</a></div></details></div></details><detailsclass="rustdoc-toggle implementors-toggle"><summary><sectionid="impl-TryFrom%3CU%3E-for-TypeArray"class="impl has-srclink"><aclass="srclink rightside"href="https://doc.rust-lang.org/1.67.0/src/core/convert/mod.rs.html#775">source</a><ahref="#impl-TryFrom%3CU%3E-for-TypeArray"class="anchor"></a><h3class="code-header">impl<T, U><aclass="trait"href="https://doc.rust-lang.org/1.67.0/core/convert/trait.TryFrom.html"title="trait core::convert::TryFrom">TryFrom</a><U> for T<spanclass="where fmt-newline">where<br> U: <aclass="trait"href="https://doc.rust-lang.org/1.67.0/core/convert/trait.Into.html"title="trait core::convert::Into">Into</a><T>,</span></h3></section></summary><divclass="impl-items"><detailsclass="rustdoc-toggle"open><summary><sectionid="associatedtype.Error"class="associatedtype trait-impl has-srclink"><ahref="#associatedtype.Error"class="anchor"></a><h4class="code-header">type <ahref="https://doc.rust-lang.org/1.67.0/core/convert/trait.TryFrom.html#associatedtype.Error"class="associatedtype">Error</a> = <aclass="enum"href="https://doc.rust-lang.org/1.67.0/core/convert/enum.Infallible.html"title="enumcore::conver